package model.shapes;

/**
 * Point is a simple class that models
 * a two dimensional point (x, y) 
 * 
 * Example Usage:
 *
 * 	Point p = Point.fromXY(700, 500); 
 * 	prn(p.toString());
 * 		(700, 500)
 * */
public class Point {

	private int x;
	private int y;
	
	//------------------------------------------
	// Constructing - public	
	
	/** Returns new Point with x and y set from params */
	public static Point fromXY(int aX, int aY) {
		return new Point(aX, aY);
	}	
	
	/** Returns new Point at origin (0, 0) */
	public static Point newOrigin() {
		return fromXY(0, 0);
	}	
	
	//------------------------------------------
	// Constructing - private

	/** Returns new Point with x and y set from params */
	private Point(int aX, int aY) {
		this.x = aX;
		this.y = aY;
	}
	
	//------------------------------------------
	// Accessing - public	
	
	public int getX() {
		return x;
	}

	public int getY() {
		return y;
	}	
	
	public void setX(int x) {
		this.x = x;
	}

	public void setY(int y) {
		this.y = y;
	}	
	
	//------------------------------------------
	// Calculating
	
	/** Transposes this point (i.e., flips x and y) */
	public void transpose() {
		int temp = this.x;
		this.x = this.y;
		this.y = temp;
	}
	
	/** Returns new point = this point plus param "other" */
	public Point plus(Point other) {
		return Point.fromXY(this.x + other.x, this.y + other.y);
	}	
	
	/** Returns new point = each dimension is multiplied by factor */
	public Point multiply(int factor) {
		return Point.fromXY(this.x * factor, this.y * factor);
	}	
	
	/** Returns new point = this point minus param "other" */
	public Point minus(Point other) {
		return Point.fromXY(this.x - other.x, this.y - other.y);
	}		
	
	//------------------------------------------
	// Common

	/** Returns "nice string" of this Point */
	public String toString() {
		return String.format("(%d, %d)", this.x, this.y); 
	}
	
	//------------------------------------------
	// Private Helpers

}