package model.shapes;

/**
 * The Rectanglee class is a simple shape class that models a Rectanglee.
 *
 * It has an upper-left and width and height.
 *
 * Y-axis is oriented downward (graphics style)
 * *
 * Example Usage:
 *
 * 	Rectanglee rec;
 *  rec = Rectanglee.fromUpperLeftWidthHeight(100, 50, 10, 5);
 * 	prn(rec.toString());
 * 		(left, top, right, bottom) = (100, 50, 110, 55)
 * */
public class Rectanglee {

	private Point upperLeft;
	private int width;
	private int height;

	//------------------------------------------
	// Constructing - public

	/** Returns new Rectanglee object with passed lat and long values */
	public static Rectanglee fromUpperLeftWidthHeight(int left, int top, int w, int h) {
		return new Rectanglee(left, top, w, h);
	}

	/** Returns new Rectanglee object with upper left (0, 0) and dimensions = 0 */
	static Rectanglee newInstance() {
		return null;
	}

	//------------------------------------------
	// Constructing - private

	/** Constructs Rectanglee with passed parameters */
	private Rectanglee(int left, int top, int w, int h) {
		this.upperLeft.setX(left);
		this.upperLeft.setY(top);
		this.width = w;
	}

	//------------------------------------------
	// Accessing

	public int getLeft() {
		return this.upperLeft.getX();
	}

	public int getRight() {
		return this.getLeft() + this.width;
	}

	public int getTop() {
		return this.upperLeft.getY();
	}

	public int getBottom() {
		return this.getTop() + this.height;
	}

	//------------------------------------------
	// Calculations

	/** Returns area of rectangle (width * height) */
	public int getArea() {
		return this.width * this.height;
	}

	/** Returns perimeter of rectangle (cumulative length of sides) */
	public int getPerimeter() {
		return 2 * (this.width + this.height);
	}

	//------------------------------------------
	// Common

	/** Returns nice display string for this Rectanglee */
	public String toString() {
		return String.format(
			"(left, top, right, bottom) = (%d, %d, %d, %d)",
			this.getLeft(), this.getTop(),
			this.getRight(), this.getBottom());
	}

}